@@ -10,7 +10,7 @@ from distutils.core import setup
 from src.About import __version__ as v
 version = v
 
-build = "852"
+build = "917"
 
 sh = ['scribo']
 desktop_file = ['scribo.desktop']
@@ -78,7 +78,7 @@ You MUST remove all application data from ~/.scribo before installing,
 e.g. with "rm -rf ~/.scribo".
 Thank you
 """,
-  author="Zaiceva Dyana, Mezhenyn Artyom, Sannikov Alexander",
+  author="Zaiceva Dyana, Mezhenyn Artyom, Sannikov Alexander, Galov Ivan",
   author_email='<maemo-scribo@cs.karelia.ru>',
   url='http://oss.fruct.org/',
   license='GPL v2',
