@@ -15,12 +15,14 @@ __license__ = "GPLv2"
 
 
 import xmlrpclib
-import urllib2
+import urllib2, urllib
 from urllib import urlencode
 import os
 import time
 import hashlib
 import socket
+import re
+import string
 
 from ldm.Message import Message, POST, COMMENT
 from ldm.Account import Account
@@ -888,34 +890,55 @@ class LivejAccount(Account, Service):
 	@param addit (Dict) unused
 	@return None
 	"""
-	misc = parent.misc
-	if parent.type == POST:
-	    ptid = 0
-	else:
-	    ptid = misc['parenttalkid']
-        req = {
-            'parenttalkid': ptid,
-            'itemid': parent.custom_id,
-            'journal': parent.journal.username,
-            'usertype': 'user',
-            'userpost': self.username,
-            'password': self.passwd,
-            'do_login': '1',
-            'subject': msg.title,
-            'subjection':'none',
-            'body':msg.text,
-        }
-        req = urlencode(req)
+	"""
+	def lookup_for_root(mesg):
+	    if mesg.type == POST:
+		return mesg
+	    else:
+		lookup_for_root(mesg.parent)
+	  """
+	  
+	req = None
+	print "sending reach LiveJAccount"
+	try:
+	    misc = parent.misc
+	    if parent.type == POST:
+		ptid = 0
+		itemid = re.findall("\d+\.html$", parent.url)[0].split('.')[0]
+	    else:
+		ptid = parent.custom_id
+		mid = sql_driver.select_cmd("SELECT id FROM Messages WHERE custom_id=? AND journal=? AND type=?",\
+		  (misc['parenttalkid'], self.id, POST))
+		print mid
+		itemid = re.findall("\d+\.html$", Message(mid).url)[0].split('.')[0]
+		#itemid = re.findall("\d+\.html$", lookup_for_root(Message(misc['parenttalkid'])).url)[0].split('.')[0]
+	  
+	    print "1"
+	    req = {
+		'parenttalkid': ptid,
+		'itemid': itemid,
+		'journal': parent.journal.username,
+		'usertype': 'user',
+		'userpost': self.username,
+		'password': self.passwd,
+		'do_login': '1',
+		'subject': msg.title,
+		'subjection':'none',
+		'body':msg.text,
+	    }
+	    print "2"
+	    req = urlencode(req)
+	except Exception, x:
+	    print  x
         print req
         try:
 	    resp = urllib2.urlopen(urllib2.Request(LJ_SHORT+"/talkpost_do.bml",req))
 	    tmp = resp.readline()
 	    resp.close()
-	    #f=open('res.html','wt')
-	    #f.write(tmp)
-	    #f.close()
         except IOError, exc:
+	    print exc
             raise SocketExc(self, exc)
+	
 
 
     def del_comment (self, msg, addit = None):
@@ -930,11 +953,25 @@ class LivejAccount(Account, Service):
 	"""
 	##FIXME: deleting by author is not supported yet
         session = self.get_session()
-        req = urllib2.Request(LJ_SHORT+"/delcomment.bml?journal=%s&id=%i" % (msg.journal,\
-             msg.custom_id),headers={'Cookie': "ljsession=%s" %(session)})
+        print msg.id
+        print msg.title
+        print msg.custom_id
+        #FIXME dirty hack!!!
+        req = urllib2.Request(LJ_SHORT+"/delcomment.bml?journal=%s&id=%s" % (msg.journal.username,\
+             int(str((int(msg.custom_id)) * 256 +5))),headers={'Cookie': "ljsession=%s" %(session)})
+        #FIXME end of dirty hack!!!
+        print req.get_full_url()
         r = urllib2.urlopen(req)
         page = r.readlines()
-        self.__confirm(page,session,{'delauthor':0,'delthread':addit['delthread']})
+        try:
+	    dthr = addit['delthread']
+	except:
+	    dthr = 0
+	try:
+	    daut = addit['delauthor']
+	except:
+	    daut = 0
+        self.__confirm(page,session,{'delauthor':daut,'delthread':dthr})
         ##FIXME: add removing from DB!!!
         
     def freeze_comment (self, msg, addit = None):
@@ -951,9 +988,10 @@ class LivejAccount(Account, Service):
             mode = 'freeze'
         else:
             mode = 'unfreeze'
-
+	#FIXME dirty hack!!!
         req=urllib2.Request(LJ_SHORT+"/talkscreen.bml?mode=%s&journal=%s&talkid=%i" % (mode, msg.journal,\
-                    msg.custom_id),headers = {'Cookie': "ljsession=%s" %(session)})
+                    int(str((int(msg.custom_id)) * 256 +5))),headers = {'Cookie': "ljsession=%s" %(session)})
+        #FIXME end of dirty hack!!!
         r = urllib2.urlopen(req)
         page = r.readlines()
         self.__confirm(page,session,None)
@@ -974,15 +1012,16 @@ class LivejAccount(Account, Service):
             mode = 'screen'
         else:
             mode = 'unscreen'
-
+	#FIXME dirty hack!!!
         req=urllib2.Request(LJ_SHORT+"/talkscreen.bml?mode=%s&journal=%s&talkid=%i" % (mode, msg.journal,\
-                    msg.custom_id),headers = {'Cookie': "ljsession=%s" %(session)})
+                    int(str((int(msg.custom_id)) * 256 +5))),headers = {'Cookie': "ljsession=%s" %(session)})
+        #FIXME end of dirty hack!!!
         r = urllib2.urlopen(req)
         page = r.readlines()
         self.__confirm(page,session,None)
 
 
-    def refresh_comments (self, addit = None):
+    def refresh_comments (self, callback, addit = None):
         """
 	update comments from livejournal
 	
@@ -995,11 +1034,8 @@ class LivejAccount(Account, Service):
 	    cp.maxid = acc_misc['acc_misc']
 	    cp.current = acc_misc['acc_misc']-1
         session = self.get_session()
-        
-        try:
-	    cp.current = acc_misc['acc_misc']
-	except:
-	    cp.current = -1
+        #Gets metadata for all comments, get data only for new
+        cp.current = -1
 	
 	once = True
         while once or cp.maxid>cp.current:
@@ -1008,6 +1044,7 @@ class LivejAccount(Account, Service):
                       %(cp.current+1), headers = {'Cookie': "ljsession=%s"%(session)})
             rxml = urllib2.urlopen(req).read()
             cp.feedmeta(rxml)
+            callback()
         
         try:
 	    cp.current = acc_misc['acc_misc']
@@ -1019,10 +1056,15 @@ class LivejAccount(Account, Service):
                       % (cp.current+1), headers = {'Cookie': "ljsession=%s"%(session)})
             rxml = urllib2.urlopen(req).read()
             cp.feeddata(rxml)
-            
+            callback()
+	try:
+	    _i = acc_misc['acc_misc']
+	except:
+	    acc_misc['acc_misc'] = 0
+	    self.misc = acc_misc
+        self.__savecomments(cp.changeset, cp.umap)
         acc_misc['acc_misc'] = cp.maxid
         self.misc = acc_misc
-        self.__savecomments(cp.changeset, cp.umap)
         
         
         
@@ -1038,17 +1080,24 @@ class LivejAccount(Account, Service):
 	"""
         ##FIXME: Needs implementation
         kl = changeset.keys()
+        print changeset
         kl.sort()
 	for i in kl:
 	    if changeset[i]['state']=='A':
+	        #comment yet added
+	        print i
+	        print self.misc
+	        if i <= self.misc['acc_misc']:
+		    continue
+		print changeset[i]
 		comment = Message()
 		comment.custom_id = i
                 comment.type = COMMENT
-		if changeset[i]['subject']==None:
+		if changeset[i].get('subject',None)==None:
 		    changeset[i]['subject'] = '(No Subject)'
 		comment.title = changeset[i]['subject']
 		comment.date = changeset[i]['date']
-		comment.text = changeset[i]['body']
+		comment.text = string.replace(changeset[i]['body'], "\n", "<br/>")
 		
 		comment.misc = {'parenttalkid':changeset[i]['jitemid'],'frozen':False,'screened':False,
 			      'deleted':False}
@@ -1057,9 +1106,7 @@ class LivejAccount(Account, Service):
 			      "so this is an error")
 		
 		
-		print umap[changeset[i]['posterid']]
-                print self.service_id
-                print sql_driver.select_mcmd("SELECT journal, custom_id FROM Messages")
+		print sql_driver.select_mcmd("SELECT id, journal, custom_id FROM Messages")
                 #acc_id = sql_driver.select_cmd("SELECT id FROM Accounts WHERE username=? AND service_id=?",\
 		#  (umap[changeset[i]['posterid']], self.service_id))
 		  
@@ -1070,9 +1117,10 @@ class LivejAccount(Account, Service):
 		par_id = changeset[i]['parentid']
 		if par_id == 0:
 		    par_id = changeset[i]['jitemid']
-                print changeset[i]
-                print par_id
+                print i
                 print self.id
+                print par_id
+                sql_driver._db.commit()
 		mid = sql_driver.select_cmd("SELECT id FROM Messages WHERE custom_id=? AND journal=?",\
 		  (par_id, self.id))
 		par_msg = Message(mid)
@@ -1084,26 +1132,40 @@ class LivejAccount(Account, Service):
 		
 		
 	    elif changeset[i]['state']=='D':
-		mid = sql_driver.select_cmd("SELECT id FROM Messages WHERE custom_id=? AND type=? AND journal=?",\
-		  (i, COMMENT, self.id))
-		scr_msg = Message(mid)
-		scr_msg.del_comment_local(self)
-		
+	        try:
+		    print "deleting" 
+		    print "SELECT id FROM Messages WHERE custom_id=%d AND type=%d AND journal=%d"\
+		              %(i, COMMENT, self.id)
+		    mid = sql_driver.select_cmd("SELECT id FROM Messages WHERE custom_id=? AND type=? AND journal=?",\
+		              (i, COMMENT, self.id))
+		    print mid
+		    scr_msg = Message(mid)
+		    print scr_msg
+		    scr_msg.del_comment_local(self)
+		except Exception,ex:
+		    print "error"+ str(ex)
+		    
 	    elif changeset[i]['state']=='F':
-		mid = sql_driver.select_cmd("SELECT id FROM Messages WHERE custom_id=? AND type=? AND journal=?",\
-		  (i, COMMENT, self.id))
-		scr_msg = Message(mid)
-		tmisc = scr_msg.misc
-		tmisc['frozen'] = not tmisc['frozen']
-		scr_msg.misc = tmisc
-		
+		try:
+		    mid = sql_driver.select_cmd("SELECT id FROM Messages WHERE custom_id=? AND type=? AND journal=?",\
+			(i, COMMENT, self.id))
+		    scr_msg = Message(mid)
+		    tmisc = scr_msg.misc
+		    tmisc['frozen'] = not tmisc['frozen']
+		    scr_msg.misc = tmisc
+		except:
+		    pass
+		    
 	    elif changeset[i]['state']=='S':
-		mid = sql_driver.select_cmd("SELECT id FROM Messages WHERE custom_id=? AND type=? AND journal=?",\
-		  (i, COMMENT, self.id))
-		scr_msg = Message(mid)
-		tmisc = scr_msg.misc
-		tmisc['screened'] = not tmisc['screened']
-		scr_msg.misc = tmisc
+		try:
+		    mid = sql_driver.select_cmd("SELECT id FROM Messages WHERE custom_id=? AND type=? AND journal=?",\
+			(i, COMMENT, self.id))
+		    scr_msg = Message(mid)
+		    tmisc = scr_msg.misc
+		    tmisc['screened'] = not tmisc['screened']
+		    scr_msg.misc = tmisc
+		except:
+		    pass
 	    else:
 		raise Warning("Illegal XML","Illegal XML recieved from LiveJournal")
 	      
@@ -1111,26 +1173,31 @@ class LivejAccount(Account, Service):
 	"""
 	Confirm operation. (get form from HTML-page, fill it and send)
 	
-	@param page (string) HTML-page source
+	@param page (string list) HTML-page source
 	@param session (string) Cookie string for auhtentification (Default None)
 	@param uparams (dict) additional params for form (Default None)
 	@return None
 	"""
-      
+	def strsinstr(srcstr, pats):
+	    for i in pats:
+		if string.find(srcstr, i)>=0:
+		    return True
+	    return False  
         if session:
             headers = {'Cookie':"ljsession=%s" %(session)}
         else:
             headers = None
 	# Finds useful content
-        pat = "<!-- your content here -->"
-        while string.find(lines.pop(0), pat) < 0:
+        pat = ("<!-- your content here -->","<!-- Content -->")
+        while not strsinstr(page.pop(0), pat):
             pass
 
-        pat = "<!-- /content -->"
-        while string.find(lines.pop(), pat) < 0:
+        pat = ("<!-- /content -->","<!-- End \#content -->")
+        while not strsinstr(page.pop(), pat):
             pass
+	  
 	#Look for form in HTML-page
-        html_data = string.join(lines)
+        html_data = string.join(page)
         parcer = CHTMLParser()
         parcer.feed(html_data)
 	#Update params by user's params
@@ -1138,7 +1205,13 @@ class LivejAccount(Account, Service):
         if uparams:
             params.update(uparams)
 	#send request
-        req=urllib2.Request(parcer.request, params, headers=headers)
+	print "============================="
+	print parcer.request
+	print urllib.urlencode(params)
+	print headers
+	print "============================="
+        req=urllib2.Request(parcer.request, urllib.urlencode(params), headers=headers)
+        print req
         r = urllib2.urlopen(req)
 
     """
