@@ -13,9 +13,9 @@ sys.path.append("../ldm")
 sys.path.append("../ui")
 sys.path.append("../services")
 
-import test.SysTest
-import test.SysFT
-import test.BDTest
+import SysTest
+import SysFT
+import BDTest
 
 
 
