@@ -279,7 +279,10 @@ class AddPostWindow(MainWindow):
                 return
         
         #if mes is draft, when remove draft and edit original message
-        id_origin = self.msg.get_option("original") 
+        try:
+            id_origin = self.msg.get_option("original") 
+        except KeyError:
+            id_origin = None
         if id_origin:
             self.msg.del_msg_tree()
             self.msg = Message(id_origin)
@@ -578,7 +581,7 @@ class AddPostWindow(MainWindow):
         """ 
         self.add_in_drafts()
         ret = QtGui.QMessageBox.information(self, self.tr("Scribo"),
-                                                self.tr("Post is edit"),
+                                                self.tr("Post was save"),
                                                 QtGui.QMessageBox.Yes)
         self.sending_post = True
         from ldm.Message import DRAFT
