@@ -4,7 +4,7 @@
   File is a part of Scribo Project
   Module implements add profile window from UI
   @author: Zaiceva Diana <zaiceva@cs.karelia.ru>
-  @date: 11.12.2009
+  @date: 23.06.2010
 """
 import sys
 
@@ -16,21 +16,20 @@ from ldm.Account import *
 from services.Dispatcher import dispatcher
 
 from ToolbarWindow import ToolbarWindow
-from StartPage import StartPage
-
+#from StartPage import StartPage
+from MainWindow import *
 __author__ = "Diana Zaiceva <zaiceva@cs.karelia.ru>"
-__version__ = "$Revision: 0.1 $"
-__date__ = "$Date: 2009/12/11 $"
+__version__ = "$Revision: 0.2 $"
+__date__ = "$Date: 2010/06/23 $"
 __copyright__ = ""
 __license__ = "GPLv2"
 
 
-class AddProfileWindow(ToolbarWindow, StartPage):
+class AddProfileWindow(MainWindow):
     """
     class for draw profile window
     @version  1.0
     @author  Zaiceva Diana <zaiceva@cs.karelia.ru>
-    @todo  auth_check
     """
     def __init__(self, parent=None, default=None):
         """
@@ -38,85 +37,94 @@ class AddProfileWindow(ToolbarWindow, StartPage):
         default = default account (for managing profile) or None (for adding profile) 
         @return
         """
-        QtGui.QWidget.__init__(self, parent.centralWidget())
+        super(AddProfileWindow, self).__init__(parent)
+
+        self.centr_widg = QtGui.QWidget(self)
         self.accounts2 = []
         self.default = default
         self.create_actions()
+        self.parent = parent
         toolbar = self.create_toolbar()
-        self.vbox_add = QtGui.QVBoxLayout()
-        login_label = QtGui.QLabel(self.tr("Login"), self)
-        login_label.setAlignment(QtCore.Qt.AlignLeft)
-        pasw_label = QtGui.QLabel(self.tr("Password"), self)
-        pasw_label.setAlignment(QtCore.Qt.AlignLeft)
-        self.login_edit = QtGui.QLineEdit(self)
-        self.pasw_edit = QtGui.QLineEdit(self)
+        self.hbox_add = QtGui.QHBoxLayout()
+
+        login_label = QtGui.QLabel(self.tr("Login"), self.centr_widg)
+        login_label.setAlignment(QtCore.Qt.AlignRight)
+        pasw_label = QtGui.QLabel(self.tr("Password"), self.centr_widg)
+        pasw_label.setAlignment(QtCore.Qt.AlignRight)
+        self.login_edit = QtGui.QLineEdit(self.centr_widg)
+        self.pasw_edit = QtGui.QLineEdit(self.centr_widg)
         self.pasw_edit.setEchoMode(QtGui.QLineEdit.Password)
         self.login_edit.setFocus()
         self.serv_combo = self.create_list_acc(self.default)
 
         grid = QtGui.QGridLayout()
         grid.addWidget(login_label, 0, 0)
-        grid.addWidget(self.login_edit, 0, 1, 1, 3, QtCore.Qt.AlignLeft)
+        grid.addWidget(self.login_edit, 0, 1, 1, 4, QtCore.Qt.AlignLeft)
         grid.addWidget(pasw_label, 1, 0)
-        grid.addWidget(self.pasw_edit, 1, 1, 1, 3, QtCore.Qt.AlignLeft)
-
-
+        grid.addWidget(self.pasw_edit, 1, 1, 1, 4, QtCore.Qt.AlignLeft)
+        service_label = QtGui.QLabel(self.tr("Blog Service"), self.centr_widg)
+        service_label.setAlignment(QtCore.Qt.AlignRight)
+        grid.addWidget(service_label, 2, 0)
         if default:
             self.login_edit.setText(self.default.username)
             self.pasw_edit.setText(self.default.passwd)
             self.login_edit.setDisabled(True)
-            service_label = QtGui.QLabel(self.tr("Service"), self)
-            service_label.setAlignment(QtCore.Qt.AlignLeft)
-            self.service_edit = QtGui.QLabel(default.get_name(), self)
-            grid.addWidget(service_label, 2, 0)
-            grid.addWidget(self.service_edit, 2, 1, 1, 3,
-                            QtCore.Qt.AlignLeft)
-
-        grid.addWidget(self.serv_combo, 3, 0)
+            self.service_edit = QtGui.QLabel(default.get_name(), self.centr_widg)
+            grid.addWidget(self.service_edit, 2, 1, 1, 4, QtCore.Qt.AlignLeft)
+            grid.addWidget(self.serv_combo, 3, 1, 1, 4, QtCore.Qt.AlignLeft)
+            grid.setRowStretch(3, 2)
+        else:
+            grid.addWidget(self.serv_combo, 2, 1, 1, 4, QtCore.Qt.AlignLeft)
+            grid.setRowStretch(2, 2)
         grid.setColumnStretch(0, 1)
-        grid.setColumnStretch(1, 2)
-
-        self.vbox_add.addWidget(toolbar)
-        self.vbox_add.addLayout(grid)
-        self.vbox_add.addStretch(1)
-        self.setLayout(self.vbox_add)
+        grid.setColumnStretch(1, 3)
+        self.setCentralWidget(self.centr_widg)
 
 
+        self.hbox_add.addWidget(toolbar)
+        self.hbox_add.addSpacing(10)
+        self.hbox_add.addLayout(grid)
+        self.centr_widg.setLayout(self.hbox_add)
+        
+        self.show()
+    
     def create_toolbar(self):
         """
-        create toolbar for window 
-        @param main_window = parent of widget from class 
+        create profile for "add profile" window
         @return
         """
-        file_tool_bar = QtGui.QToolBar("", self)
-        file_tool_bar.setIconSize(QtCore.QSize(64, 64))
-        file_tool_bar.addAction(self.back_act)
-        file_tool_bar.addAction(self.home_act)
+        file_tool_bar = ToolbarWindow(parent=self.centr_widg)
         if self.default:
-            file_tool_bar.addAction(self.del_act)
-        file_tool_bar.addAction(self.add_acc)
+            file_tool_bar.addWidget(self.del_act)
+        file_tool_bar.addWidget(self.add_acc)
+        self.connect(file_tool_bar.home_act, QtCore.SIGNAL("clicked()"),
+                             self.home_window)                             
         return file_tool_bar
 
-
     def create_actions(self):
         """ 
         create buttons for toolbar
         @return
         """
-        if self.default:
-            self.del_act = QtGui.QAction(self.tr("&Delete"), self)
-            #self.del_act.setStatusTip(self.tr("Delete account"))
-            self.del_act.setIcon(QtGui.QIcon("../data/delete.png"))
-            self.connect(self.del_act, QtCore.SIGNAL("activated()"),
-                         self.del_account_ui)
-
-        self.add_acc = QtGui.QAction(self.tr("&OK"), self)
-        #self.add_acc.setStatusTip(self.tr("Add profile"))
-        self.add_acc.setIcon(QtGui.QIcon("../data/ok.png"))
-        self.connect(self.add_acc, QtCore.SIGNAL("triggered()"),
+        self.add_acc = QtGui.QToolButton(self.centr_widg)
+        self.connect(self.add_acc, QtCore.SIGNAL("clicked()"),
                      self.add_account)
+        if self.default:
+            self.del_act = QtGui.QToolButton(self.centr_widg)
+            self.del_act.setIcon(QtGui.QIcon("../data/en/remove_profile.png"))
+            self.del_act.setText(self.tr("Delete account"))
+            self.del_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
+            self.del_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
+            self.connect(self.del_act, QtCore.SIGNAL("clicked()"),
+                         self.del_account_ui)
+            self.add_acc.setIcon(QtGui.QIcon(self.tr("../data/en/change_profile_ok.png")))
+            self.add_acc.setText(self.tr("OK"))
+        else:
+            self.add_acc.setIcon(QtGui.QIcon(self.tr("../data/en/add_profile.png")))
+            self.add_acc.setText(self.tr("Add account"))
 
-        super(AddProfileWindow, self).create_actions()
+        self.add_acc.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
+        self.add_acc.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
 
 
     def create_list_acc(self, default):
@@ -126,7 +134,7 @@ class AddProfileWindow(ToolbarWindow, StartPage):
          manage account
         @return acc_combo pop-up list with accounts or services
         """
-        acc_combo = QtGui.QComboBox(self)
+        acc_combo = QtGui.QComboBox(self.centr_widg)
         self.accounts2 = []
         if default:
             self.accounts2.append(default)
@@ -178,7 +186,7 @@ class AddProfileWindow(ToolbarWindow, StartPage):
         """
         if (self.login_edit.text() == "") or (self.pasw_edit.text() == ""):
             QtGui.QMessageBox.information(self, self.tr("Scribo"),
-                               self.tr("Please, fill all  lines!"),
+                               self.tr("Please, fill all fields!"),
                                QtGui.QMessageBox.Yes)
             return
 
@@ -188,36 +196,62 @@ class AddProfileWindow(ToolbarWindow, StartPage):
             ret = self._add_new_account()
 
         if ret:
-            main_window.home_window()
-
-
-
+            super(AddProfileWindow, self).reload_home_window()
+    
     def _edit_account(self):
 
-        acc = type(self.default)()
 
-        acc.username = str(self.login_edit.text())
-        acc.passwd = str(self.pasw_edit.text())
+        old_pass = self.default.passwd
+
+        self.default.passwd = str(self.pasw_edit.text())
 
         try:
-            acc.check_login()
+            self.default.check_login()
         except WarningExc, exc:
-            acc.del_account()
-            main_window.show_warning(exc)
+            self.default.passwd = old_pass
+            super(AddProfileWindow,self).show_warning(exc)
             return False
 
         try:
             self.default.refresh_user_info()
         except WarningExc, exc:
-            main_window.show_warning(exc)
+            super(AddProfileWindow,self).show_warning(exc)
 
-        self.default.passwd = str(self.pasw_edit.text())
         self.default.set_default()
-        acc.del_account()
 
         return True
 
 
+    def _add_new_account(self):
+        index = self.serv_combo.currentIndex()
+
+        service = dispatcher.get_services()[index]
+        username = unicode(self.login_edit.text())
+        username = username.lower()
+        username = username.replace('-','_')
+        acc = Account.register(service, username)
+        acc.passwd = unicode(self.pasw_edit.text())
+
+        main_prof.add_account(acc)
+
+        try:
+            acc.check_login()
+        except WarningExc, exc:
+            main_prof.remove_account(acc)
+            super(AddProfileWindow, self).show_warning(exc)
+            return False
+
+        try:
+            acc.refresh_user_info()
+        except WarningExc, exc:
+            main_prof.remove_account(acc)
+            super(AddProfileWindow, self).show_warning(exc)
+            return False
+
+        acc.set_default()
+
+        return True
+
     def del_account_ui(self):
         """
         deleting account 
@@ -225,7 +259,7 @@ class AddProfileWindow(ToolbarWindow, StartPage):
         @return 
         """
         ret = QtGui.QMessageBox.information(self, self.tr("Scribo"),
-                               self.tr("Do you really want delete account?"),
+                               self.tr("Do you really want to delete account?"),
                                QtGui.QMessageBox.Yes,
                                QtGui.QMessageBox.No)
         if (ret == QtGui.QMessageBox.No):
@@ -240,13 +274,10 @@ class AddProfileWindow(ToolbarWindow, StartPage):
                 main_prof.def_account = self.default
             del_acc.del_account()
             ret = QtGui.QMessageBox.information(self, self.tr("Scribo"),
-                                   self.tr("Account is deleted"),
+                                   self.tr("Account was deleted"),
                                    QtGui.QMessageBox.Yes)
 
         else:
             #all accounts are deleted
-            del_acc.del_account()
-        main_window.home_window()
-
-
-from MainWindow import *
+    	    main_prof.remove_account(del_acc)
+        super(AddProfileWindow, self).reload_home_window()
