@@ -93,19 +93,19 @@ class HomePage(MainWindow):
         print def_acc
         info = self.tr("<h2>Personal info:</h2><br>")
         if def_acc.nick:
-            print def_acc.nick
+            #print def_acc.nick
             info = info + self.tr("<div>Nick: <b>")\
             + QtCore.QString(def_acc.nick) + self.tr("</b></div>")
         if def_acc.date_of_birth:
-            print def_acc.date_of_birth
+            #print def_acc.date_of_birth
             info = info + self.tr("<div>Birthday: <b>")\
             + QtCore.QString(def_acc.date_of_birth) + self.tr("</b></div>")
         if def_acc.city:
-            print def_acc.city
+            #print def_acc.city
             info = info + self.tr("<div>City: <b>")\
             + QtCore.QString(def_acc.city) + self.tr("</b></div>")
         if def_acc.get_name():
-            print def_acc.get_name()
+            #print def_acc.get_name()
             info = info + self.tr("<div>Blog service: <b>")\
             + QtCore.QString(def_acc.get_name()) + self.tr("<b><br></div>")
         return info
