@@ -348,7 +348,7 @@ class ListMyPosts(MainWindow):
         cancel_button = self.f_dial.addButton(QtGui.QMessageBox.Abort)
         cancel_button.hide()
         
-        if self.filter_list:
+        if self.flag_is_filter:
             hbox.addWidget(self.find_in_found, -1, QtCore.Qt.AlignVCenter)
             self.find_in_found.adjustSize()
       
