@@ -32,6 +32,17 @@ class MainWindow(QtGui.QMainWindow):
         @return 
         """
         QtGui.QMainWindow.__init__(self, parent)
+        from ConfigDriver import config
+        font = QtGui.QFont()
+        str_font = None
+        try:
+            str_font = config.get('UI', 'font')
+        except:
+            config.set('UI', 'font', None)
+        if str_font:
+            ok = font.fromString(str_font)
+            if font and ok:
+                self.setFont(font)
         self.setWindowTitle(self.tr("Scribo"))
         self.setMinimumSize(160, 160)
         self.resize(480, 340)
@@ -74,6 +85,7 @@ class MainWindow(QtGui.QMainWindow):
         @return
         """
         self.dial = QtGui.QMessageBox()
+        self.dial.setWindowTitle(self.tr("Draft"))
         self.list_drafts = self.view_list_drafts()
         vbox = QtGui.QVBoxLayout()
         but_box = QtGui.QDialogButtonBox()
@@ -133,7 +145,7 @@ class MainWindow(QtGui.QMainWindow):
             author = mes.poster
             icon = ""
             if author:
-               text = text + "  (" + author + ")"
+               text = text.decode('utf8') + "  (" + str(author.username).decode('utf8') + ")"
                icon = author.get_icon()
                if not icon:
                    icon = ""
@@ -210,6 +222,142 @@ class MainWindow(QtGui.QMainWindow):
                                   self.tr("Scribo"),
                                   exc.to_html(),
                                   QtGui.QMessageBox.Ok)
+    def settings_change(self):
+        """  
+        page with info about application
+        @param 
+        @return
+        """
+        self.dial_set = QtGui.QMessageBox()
+        self.dial_set.setWindowTitle(self.tr("Settings"))
+        
+        from ConfigDriver import config
+        proxy = config.get('Main', 'proxy')
+        
+        self.check_proxy = QtGui.QCheckBox(self.tr("Use proxy connections"), self.dial_set)
+        self.check_proxy.adjustSize()
+        self.connect(self.check_proxy, QtCore.SIGNAL("stateChanged (int)"), self.change_set_proxy)
+      
+        label_proxy = QtGui.QLabel(self.tr("Proxy: "))
+        label_port = QtGui.QLabel(self.tr("Port: "))
+        label_font = QtGui.QLabel(self.tr("Font: "))
+        
+        self.edit_font = QtGui.QLineEdit()
+        self.edit_font.setMinimumWidth(500)
+        self.font = config.get('UI', 'font')
+        if self.font:
+            font = QtGui.QFont()
+            ok = font.fromString(self.font)
+            if ok:
+                self.edit_font.setText(self.parse_font(font))
+        self.push_font = QtGui.QPushButton(self.tr("Choose font"), self.dial_set)
+               
+        self.edit_proxy = QtGui.QLineEdit()
+        self.edit_proxy.setMinimumWidth(350)
+        
+        self.edit_port = QtGui.QLineEdit()
+        self.edit_port.setMinimumWidth(350)
+        self.edit_port.setValidator(QtGui.QRegExpValidator(QtCore.QRegExp("^[1-9]{1,5}$"),self))
+        self.edit_proxy.setDisabled(True)
+        self.edit_port.setDisabled(True)
+        self.edit_font.setDisabled(True)
+        
+        if proxy:
+            self.check_proxy.setCheckState(QtCore.Qt.Checked)
+            list_proxy = QtCore.QString(proxy).split(":")
+            self.edit_proxy.setDisabled(False)
+            self.edit_port.setDisabled(False)
+            self.edit_proxy.setText(list_proxy[0])
+            self.edit_port.setText(list_proxy[1])
+            
+            
+        self.dial_set.layout().addWidget(self.check_proxy, 0, 0, 1, 2, QtCore.Qt.AlignLeft)  
+        self.dial_set.layout().addWidget(label_proxy, 1 ,0, QtCore.Qt.AlignLeft)
+        self.dial_set.layout().addWidget(self.edit_proxy, 1 ,1, 1, 2, QtCore.Qt.AlignLeft)
+        self.dial_set.layout().addWidget(label_port, 2 ,0, QtCore.Qt.AlignLeft)
+        self.dial_set.layout().addWidget(self.edit_port, 2 ,1 ,1 ,2, QtCore.Qt.AlignLeft)
+        self.dial_set.layout().addWidget(label_font, 3 ,0 , QtCore.Qt.AlignLeft)
+        self.dial_set.layout().addWidget(self.push_font, 3 ,1 , QtCore.Qt.AlignLeft)
+        self.dial_set.layout().addWidget(self.edit_font, 4 ,0 ,1 ,2, QtCore.Qt.AlignLeft)
+        
+        self.connect(self.push_font, QtCore.SIGNAL("clicked()"),
+                     self.choose_font)
+       
+        cancel_button = self.dial_set.addButton(QtGui.QMessageBox.Abort)
+        ok_button = self.dial_set.addButton(QtGui.QMessageBox.Ok)
+        cancel_button.hide()
+         
+        self.dial_set.exec_()
+        if self.dial_set.clickedButton() == cancel_button:
+            pass
+        elif self.dial_set.clickedButton() == ok_button:
+             self.save_settings() 
+        else:
+            return
+            
+    def save_settings(self):
+        proxy = self.edit_proxy.text()
+        port = self.edit_port.text()
+        from ConfigDriver import config
+        if self.check_proxy.checkState() == QtCore.Qt.Unchecked:
+            try:
+                config.set('Main', 'proxy', None)
+            except WarningExc, e:
+                self.show_warning(e)
+        else:
+            try:
+                config.set('Main', 'proxy', str(proxy+":"+port))
+            except WarningExc, e:
+                self.show_warning(e)
+        if self.font:
+            try:
+                config.set('UI', 'font', str(self.font))
+            except WarningExc, e:
+                self.show_warning(e)            
+   
+    def choose_font(self):
+        font, ok = QtGui.QFontDialog.getFont(QtGui.QFont("Helvetica [Cronyx]", 10), self.dial_set)
+        if ok:
+            self.font = font.toString()
+            self.edit_font.setText(self.parse_font(font))
+            
+    def parse_font(self, font):
+        family = font.family()
+        bold = font.bold()
+        italic = font.italic()
+        overline = font.overline()
+        point_size = font.pointSize()
+        pixel_size = font.pixelSize()
+        style = font.style()
+        disp_font = family
+        if bold:
+            disp_font+= ", bold"
+        if italic:
+            disp_font+= ", italic"
+        if overline:
+            disp_font+= ", overline"
+        if point_size <> -1:
+            disp_font+= ", " + str(point_size)
+        elif pixel_size <> -1:
+            disp_font+= ", "+ str(pixel_size)
+        if style == QtGui.QFont.StyleNormal:
+            disp_font+= ", style - normal"
+        elif style == QtGui.QFont.StyleItalic:
+            disp_font += ", style - italic"
+        elif style == QtGui.QFont.StyleOblique:
+            disp_font += ", style - oblique"
+        return disp_font
+            
+
+        
+    def change_set_proxy(self, state):
+        if state == QtCore.Qt.Unchecked:
+            self.edit_proxy.setDisabled(True)
+            self.edit_port.setDisabled(True)
+        else:
+            self.edit_proxy.setDisabled(False)
+            self.edit_port.setDisabled(False)
+        
 
 
     def create_actions_menu(self):
@@ -236,6 +384,9 @@ class MainWindow(QtGui.QMainWindow):
 
         self.about_act = QtGui.QAction(self.tr("&About"), self)
         self.connect(self.about_act, QtCore.SIGNAL("triggered()"), self.about)
+        
+        self.settings_act = QtGui.QAction(self.tr("&Settings"), self)
+        self.connect(self.settings_act, QtCore.SIGNAL("triggered()"), self.settings_change)
 
         self.draft_act = QtGui.QAction(self.tr("Drafts"), self)
         self.connect(self.draft_act, QtCore.SIGNAL("triggered()"), self.draft)
@@ -252,6 +403,7 @@ class MainWindow(QtGui.QMainWindow):
         self.main_menu.addAction(self.manage_act)
         self.main_menu.addAction(self.about_act)
         self.main_menu.addAction(self.draft_act)
+        self.main_menu.addAction(self.settings_act)
         self.main_menu.addSeparator()
         self.main_menu.addAction(self.exit_act)
 
