@@ -121,6 +121,8 @@ class StartPage(MainWindow):
 
         service = dispatcher.get_services()[index]
         username = unicode(self.login_edit.text())
+        username = username.lower()
+        username = username.replace('-','_')
         acc = Account.register(service, username)
         acc.passwd = unicode(self.pasw_edit.text())
 
