@@ -35,7 +35,6 @@ class ToolbarWindow(QtGui.QToolBar):
         else:
             self.setAllowedAreas(QtCore.Qt.LeftToolBarArea)
             self.create_actions()
-            #self.addWidget(self.back_act)
             self.addWidget(self.home_act)
 
 
@@ -44,21 +43,10 @@ class ToolbarWindow(QtGui.QToolBar):
         create buttons for toolbar
         @return
         """
-        """
-        self.back_act = QtGui.QToolButton(self)
-        self.back_act.setIcon(QtGui.QIcon(main_window.tr('../data/en/back.png')))
-        self.back_act.setText(self.tr("Back"))
-        self.back_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
-        self.back_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
-        self.connect(self.back_act, QtCore.SIGNAL("clicked()"),
-                     main_window.back_window)
-        """
         self.home_act = QtGui.QToolButton(self)
         self.home_act.setIcon(QtGui.QIcon(main_window.tr('../data/en/home.png')))
         self.home_act.setText(self.tr("Home"))
         self.home_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
         self.home_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
-        #self.connect(self.home_act, QtCore.SIGNAL("clicked()"),
-        #             main_window.home_window)
 
 
