@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 """
  @file: ViewMessage.py
   File is a part of Scribo Project
@@ -81,10 +82,11 @@ class ViewMessage(MainWindow):
             QNetworkProxy.setApplicationProxy(proxy)
 
         self.view_mes_widget = QWebView(self.centr_widg)
+        self.view_mes_widget.page().setLinkDelegationPolicy(QWebPage.DontDelegateLinks)
         self.hbox.addWidget(toolbar)
-        self.hbox.addSpacing(5)
+        #self.hbox.addSpacing(5)
         self.hbox.addWidget(self.view_mes_widget)
-        self.hbox.addSpacing(5)
+        #self.hbox.addSpacing(5)
         self.hbox.addWidget(sec_toolbar)
         self.centr_widg.setLayout(self.hbox)
         self.setCentralWidget(self.centr_widg)
@@ -103,6 +105,7 @@ class ViewMessage(MainWindow):
         title = msg.title
         text = msg.text
         #print "text do tidylib"+text
+
         user = msg.poster
         date = msg.date
         parent = msg.parent
@@ -133,23 +136,38 @@ class ViewMessage(MainWindow):
         if not parent_text:
             parent_text = ""
         #text = self.text_br(text)
+        
+        from ConfigDriver import config
+        font = QtGui.QFont()
+        str_font = None
+        style_font = ""
+        try:
+            str_font = config.get('UI', 'font')
+        except:
+            config.set('UI', 'font', None)
+        if str_font:
+            ok = font.fromString(str_font)
+            if font and ok:
+                style_font = "font:"+self.parse_font(font)+";"
+            else:
+                style_font = ""
+
         #print text
         header_html = '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">\
                        <html xmlns="http://www.w3.org/1999/xhtml">\
                        <head><meta http-equiv="Content-Type" content="text/html; charset=utf-8"/>\
                        <title>iframe</title>\
-                       <style type="text/css">HTML, BODY { background:transparent; padding:0; margin:0; border:0; overflow:hidden; }\
-                       .scrib_stl {font: 14pt sans-serif;}\
+                       <style type="text/css">HTML, BODY { background:transparent; padding:0; margin:0; border:0; overflow:hidden;}\
+                       .scribo_stl {%s}\
                        .tags {font: 12pt; color: red; text-decoration:underline}\
-                       .date {font-variant:small-caps; color: red;left: -12px;}\
-                       .author {font-weight: 600;}\
-                       </style></head>'
-
+                       .date {font-variant:small-caps; color: #e81f37;left: -12px;}\
+                       .author {font-weight: 600; color: #e81f37;}\
+                       </style></head>'%(style_font)
+        
         code_html =  header_html + '<body style="-moz-user-select: none; -khtml-user-select: none; user-select: none;">'\
         + '<h3><div class="title">%s</div></h3>' % (title)+'<br/><div class="author">%s</div>' % (author)\
         + '<div class="date">%s</div>' % (date) + '<br/><div class="scribo_stl"> %s </div>' % (unicode(text))\
-        + '<br/><div class="tags">%s</div></body></html>' % (unicode(tags))
-        #print code_html 
+        + '<br/><div class="tags">%s</div></body></html>'% (unicode(tags))
         """
         #version with comment
         self.view_mes_widget.setHtml("<head><meta http-equiv=\"Content-Type\" \
@@ -163,15 +181,14 @@ class ViewMessage(MainWindow):
                     + tags + self.tr("<br/>" "<b> Text:\
                     </b><br />") + text + "<br/>")
         """
-        self.view_mes_widget.setHtml(code_html)
+        self.view_mes_widget.setHtml(code_html, QtCore.QUrl.fromLocalFile("."))
+        print code_html
         del(title)
         del(text)
         del(user)
         del(date)
         del(parent)
 
-
-
     def text_escape(self, text):
         """
         check on javascript injection    
@@ -201,11 +218,18 @@ class ViewMessage(MainWindow):
         """
         file_tool_bar = ToolbarWindow(parent=self.centr_widg)
         file_tool_bar.addWidget(self.edit_act)
-        #file_tool_bar.addWidget(self.comment_act)
+        file_tool_bar.addWidget(self.comment_act)
         #file_tool_bar.addWidget(self.tree_act)
         self.connect(file_tool_bar.home_act, QtCore.SIGNAL("clicked()"),
                              self.home_window)
-
+        flag_our_post = False
+        our_acc = self.msg.journal
+        for acc in main_prof.accounts:
+            if acc == our_acc:
+                flag_our_post = True
+                
+        #self.tree_act.setDisabled(not(flag_our_post))
+        
         if not self.msg.is_editable():
             self.edit_act.setDisabled(True)
         return file_tool_bar
@@ -267,15 +291,15 @@ class ViewMessage(MainWindow):
         self.incr_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
         self.connect(self.incr_act, QtCore.SIGNAL("clicked()"),
                      self.incr_font)
-        """
+        
         self.comment_act = QtGui.QToolButton(self.centr_widg)
-        self.comment_act.setIcon(QtGui.QIcon("../data/add_post.png"))
+        self.comment_act.setIcon(QtGui.QIcon("../data/en/add_post.png"))
         self.comment_act.setText(self.tr("Write comment"))
         self.comment_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
         self.comment_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
         self.connect(self.comment_act, QtCore.SIGNAL("clicked()"),
                      self.write_comment)
-        """
+        
         self.edit_act = QtGui.QToolButton(self.centr_widg)
         self.edit_act.setIcon(QtGui.QIcon(self.tr("../data/en/post_edit.png")))
         self.edit_act.setText(self.tr("Edit"))
@@ -283,15 +307,15 @@ class ViewMessage(MainWindow):
         self.edit_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
         self.connect(self.edit_act, QtCore.SIGNAL("clicked()"),
                      self.edit_post)
-        """
-        self.tree_act = QtGui.QToolButton(self.centr_widg)
-        #self.tree_act.setIcon(QtGui.QIcon("../data/tree.png"))
-        self.tree_act.setText(self.tr("Tree of comments"))
-        self.tree_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
-        self.tree_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
-        self.connect(self.tree_act, QtCore.SIGNAL("clicked()"),
-                     self.tree_comments)
-        """
+        
+        #self.tree_act = QtGui.QToolButton(self.centr_widg)
+        #self.tree_act.setIcon(QtGui.QIcon("../data/en/tree_comment.png"))
+        #self.tree_act.setText(self.tr("Comments"))
+        #self.tree_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
+        #self.tree_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
+        #self.connect(self.tree_act, QtCore.SIGNAL("clicked()"),
+         #            self.tree_comments)
+        
 
     def view_prev_message(self):
         """
@@ -331,12 +355,48 @@ class ViewMessage(MainWindow):
             self.reload_window()
 
     def incr_font(self):
-        zoom = self.view_mes_widget.textSizeMultiplier()
-        self.view_mes_widget.setTextSizeMultiplier(zoom + 0.1)
+        zoom = self.view_mes_widget.zoomFactor()
+        self.view_mes_widget.setZoomFactor(zoom + 0.1)
 
     def decr_font(self):
-        zoom = self.view_mes_widget.textSizeMultiplier()
-        self.view_mes_widget.setTextSizeMultiplier(zoom - 0.1)
+        zoom = self.view_mes_widget.zoomFactor()
+        self.view_mes_widget.setZoomFactor(zoom - 0.1)
+        
+    def parse_font(self, font):
+        family = font.family()
+        bold = font.bold()
+        italic = font.italic()
+        overline = font.overline()
+        point_size = font.pointSize()
+        pixel_size = font.pixelSize()
+        style = font.style()
+        style_hint = font.styleHint()
+        disp_font = ""
+        if bold:
+            disp_font += " bold"
+        if italic:
+            disp_font += " italic"
+        if overline:
+            disp_font += " overline"
+        if style == QtGui.QFont.StyleNormal:
+            disp_font += " normal"
+        elif style == QtGui.QFont.StyleItalic:
+            disp_font += " italic"
+        elif style == QtGui.QFont.StyleOblique:
+            disp_font += " oblique"
+        if point_size <> -1:
+            disp_font += " " + str(point_size)+"pt"
+        elif pixel_size <> -1:
+            disp_font += " "+ str(pixel_size)+"pt"
+        if style_hint == QtGui.QFont.SansSerif or style_hint == QtGui.QFont.Helvetica:
+            disp_font += " sans-serif"
+        if style_hint == QtGui.QFont.Serif or style_hint == QtGui.QFont.Times:
+            disp_font += " serif"
+        if style_hint == QtGui.QFont.TypeWriter or style_hint == QtGui.QFont.Courier:
+            disp_font += " monospace"
+        if style_hint == QtGui.QFont.OldEnglish or style_hint == QtGui.QFont.Decorative:
+            disp_font += " fantasy"
+        return disp_font
  
     def write_comment(self):
         """
@@ -357,13 +417,13 @@ class ViewMessage(MainWindow):
     
 
 
-    def tree_comments(self):
+    #def tree_comments(self):
         """
         window with tree message
         @param
         @return                                                      
         """
-        tree_widg = TreeMessage(self, self.msg)
+       # tree_widg = TreeMessage(self, self.msg)
     
 
 
